Contributing — mod_wsgi 4.8.0 documentation

# Contributing

The mod_wsgi package is a solo effort by Graham Dumpleton.

The package is developed purely in the author’s spare time and is not funded in any way by a company, nor is it developed for a specific companies requirements. In fact the author doesn’t even develop it for his own needs. It is developed purely because it represents an interesting technical challenge and not because the author needs it himself to host a significant web site.

## How to make a donation

If you use mod_wsgi and wish to show your appreciation, donations can be made via PayPal or an Amazon (USA store only) gift certificate sent to Graham.Dumpleton at gmail dot com.

A suggested formula for how much to donate is:

- If using mod_wsgi for personal use, then consider donating what you would pay for one months worth of a single host used to run your own site.
- If using mod_wsgi for a company web site, then consider donating what you would pay for two months worth of a single host used to run that site.
- If using mod_wsgi as part of a web hosting service which you then charge other people for using, then consider donating what you would pay for three months worth of a single host used to run that site.

In other words, if you feel inclined, donate an amount commensurate with how much benefit you are getting from mod_wsgi. The reference to the cost of hosting is used at it reflects in some way how much you can afford or might be willing to pay for a hosting service yourself.

On that basis, donations might realistically range from $5 up to $150 or more. Obviously where your company spends ridiculous amounts of money on web hosting you can instead elect to donate something more within the range stated above rather than how much you actually spend on web hosting services.

Now for the reality, which is that it is very rare that a company will ever donate any money to an Open Source project. As such, when donations have occassionally been received (which doesn’t happen very often), they are from individuals using mod_wsgi themselves.

Some people do openly begrudge Open Source projects soliciting donations, but the amounts received overall are so insignificant in comparison to how much effort is generally put into projects and what a developer would need to survive that anything received is more a symbolic gesture, more than anything else, of ones appreciation.

Given that donations invariably are from individuals, do know that they are accepted with much gratitude and appreciation in return that you are at least, even if companies aren’t, trying to help support Open Source projects in some way.

## How else can you donate

If you are an author of a book related to Apache, Python, Docker or any other technologies which go into providing web hosting services, then will also happily accept an electronic copy of the book for reference.

Still don’t think a monetary contribution is something you would do, you can also simply send a Twitter message to the author expressing your appreciation. You will be surprised how far positive encouragement and appreciation can go with people who work on Open Source projects. This is because in part satisfaction comes from knowing people are benefiting from the work being done. If you never do or say anything, then Open Source developers will never know that you do appreciate the work they do, so don’t be quiet when an Open Source project is of value to you, at least say ‘Thank You’.

## How are donations used

Any monetary donations typically go towards buying clothes, toys, music, books and apps for the authors 2 children. They are therefore used as a special treat for the authors kids.

## Source code contributions

You might be thinking, what about source code contributions. Although it would be great for this project to grow to have multiple developers working on the code and documentation, reality is that working inside of Apache and the Python C APIs is quite specialised. It isn’t therefore the most attractive of projects in that regard. If however you are keen, then would love to hear from you.

## Open Source free loaders

If you are the sort of person who thinks that the Internet exists only to provide you with free stuff and where you think everyone out there exists purely to help you work out your problems, then it may be better that you go use some other WSGI server project.

Even if you don’t contribute as described above, if you at least recognise that other people are giving up their time to help you and that you put in some effort yourself to resolve a problem first, and then explain it properly in some detail to others when seeking help, providing answers to any questions asked of you, then you will still be helped.

The worst sort of people, which hopefully you don’t want to be one of, are those who simply say something is broken but will not provide sufficient details, thereby forcing other people to waste huge amounts of time dragging out the information required to help you, or having to guess what your problem is.

It is people in this latter category which are becoming a significant drain on the time of developers of Open Source projects and which are a part of why so many Open Source developers are experiencing burnout. So if you are the sort to expect people to help you, complain about things when the problem is really your own unwillingness to learn, and generally give nothing positive in return, even if only encouragement, then don’t expect to be helped. Your like has caused too much damage in the past already to any number of Open Source projects and will not be tolerated here. The mental health of Open Source developers is more important than you are.